import { Store } from './index';
export declare class RootStore<T extends object> extends Store<T> {
    private batchCount;
    constructor(state: T);
    set(value: T): void;
    delete(): void;
    state(): T;
    /**
     * Turns off this store's observables while `func` is executing, emitting only once afterward, if the store changed. This allows you to batch multiple mutations into a single update at the end.
     *
     * ```ts
     * store.batch(() => {
     *   store.assign({ key1: value1 });
     *   store('key2').delete();
     *   store('key3').set({ key4: value4 });
     *
     *   store('key1').state(); // returns `value1`
     * });
     * ```
     */
    batch(func: VoidFunction): void;
    refersToSameStateAs(other: Store<T>): boolean;
    protected maybeEmit(): void;
    protected maybeActivate(): void;
    protected maybeDeactivate(): void;
}
